package controllers

import (
	"SCRM/enums"
)

type BaseAPIController struct {
	BaseController
}

// 输出数据格式化
/*
	success json:
	{
		"state": 1,
		"code": 0,
		"data": json,
	}

	fail json:
	{
		"state": 0,
		"code": int,
		"msg": string,
	}
*/
func (this *BaseAPIController) ServeSuccessJSON(data map[string]interface{}) {
	this.Data["json"] = enums.MakeSuccessResponseJSON(data)
	this.ServeJSON()
}

func (this *BaseAPIController) ServeFailJSONWithSGJErrorCode(code int) {
	this.Data["json"] = enums.MakeFailResponseJSONWithSGJErrorCode(code)
	this.ServeJSON()
}

func (this *BaseAPIController) ServeFailJSONWithSGJError(err *enums.SGJError) {
	this.Data["json"] = enums.MakeFailResponseJSONWithSGJError(err)
	this.ServeJSON()
}

func (this *BaseAPIController) ServeFailJsonSend(code int, msg string) {
	this.Data["json"] = enums.MakeFailResponseJSON(msg, code)
	this.ServeJSON()
}

type BaseAuthAPIController struct {
	BaseAPIController
}

func (this *BaseAuthAPIController) Prepare() {
	this.BaseAPIController.Prepare()
	if this.GetAdminUserInfo() == nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeNotLogin)
		this.StopRun()
	}
}

type BaseServeAPIController struct {
	BaseAPIController
}

func (this *BaseServeAPIController) Prepare() {
	this.BaseAPIController.Prepare()
	if this.GetAdminUserInfo() == nil {
		this.ServeFailJSONWithSGJErrorCode(enums.ErrorCodeNotLogin)
		this.StopRun()
	}
}
